pub struct Client { /* private fields */ }Expand description
One CLI ↔ daemon connection.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn connect(socket: impl Into<PathBuf>) -> Result<Self>
pub fn connect(socket: impl Into<PathBuf>) -> Result<Self>
Connect to the daemon at socket. Returns the connected client
or an error if the socket is missing / unreachable.
Sourcepub fn connect_with_retry(
socket: impl AsRef<Path>,
timeout: Duration,
) -> Result<Self>
pub fn connect_with_retry( socket: impl AsRef<Path>, timeout: Duration, ) -> Result<Self>
Connect, retrying for timeout if the socket is missing —
useful immediately after spawning the daemon.
pub fn socket(&self) -> &Path