pub struct Response {
pub warnings: Vec<Warning>,
pub envelope: Envelope,
pub body: Vec<String>,
}Expand description
One full response: warnings + envelope + body lines.
Fields
warnings: Vec<Warning>envelope: Envelopebody: Vec<String>Implementations
Sourceimpl Response
impl Response
Sourcepub fn head(&self) -> ResponseHead
pub fn head(&self) -> ResponseHead
Return the response head, useful when the body is irrelevant (e.g. for re-encoding to print to the user).
Sourcepub fn render_wire(&self) -> String
pub fn render_wire(&self) -> String
Re-emit the response in canonical wire form, including the
trailing blank line. Used by --json=off (the default) to
stream the daemon’s response to stdout verbatim.